@@ -2,7 +2,7 @@
 
 // #![allow(dead_code, unused_imports)]
 
-use mpstthree::binary::struct_trait::{End, Recv, Send, Session};
+use mpstthree::binary::struct_trait::{end::End, recv::Recv, send::Send, session::Session};
 use mpstthree::role::broadcast::RoleBroadcast;
 use mpstthree::role::end::RoleEnd;
 use mpstthree::{
@@ -11,6 +11,7 @@ use mpstthree::{
 };
 
 use rand::{thread_rng, Rng};
+
 use std::error::Error;
 
 // global protocol Smtp(role S, role C)
@@ -864,15 +865,9 @@ fn endpoint_s_10(s: EndpointS10) -> Result<(), Box<dyn Error>> {
 
 ///
 
-fn all_mpst() -> Result<(), Box<dyn Error>> {
+fn main() {
     let (thread_c, thread_s) = fork_mpst(endpoint_c_0, endpoint_s_0);
 
     thread_c.join().unwrap();
     thread_s.join().unwrap();
-
-    Ok(())
-}
-
-fn main() {
-    assert!(all_mpst().is_ok());
 }
