@@ -1,4 +1,4 @@
-use crate::binary::struct_trait::{End, Signal};
+use crate::binary::struct_trait::{end::End, end::Signal};
 use std::boxed::Box;
 use std::error::Error;
 use std::mem;
