@@ -58,7 +58,7 @@ impl<R1: Role, R2: Role> Role for RoleCtoAll<R1, R2> {
 
     #[doc(hidden)]
     fn head_str() -> String {
-        String::from("RoleCtoAll")
+        "RoleCtoAll".to_string()
     }
 
     #[doc(hidden)]
@@ -71,4 +71,20 @@ impl<R1: Role, R2: Role> Role for RoleCtoAll<R1, R2> {
             R2::tail_str()
         )
     }
+
+    #[doc(hidden)]
+    fn self_head_str(&self) -> String {
+        "RoleCtoAll".to_string()
+    }
+
+    #[doc(hidden)]
+    fn self_tail_str(&self) -> String {
+        format!(
+            "{}<{}> + {}<{}>",
+            R1::head_str(),
+            R1::tail_str(),
+            R2::head_str(),
+            R2::tail_str()
+        )
+    }
 }
